#
# spec file
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global flavor %{nil}
%if "%{flavor}" == "test"
%define psuffix -test
%bcond_without test
%else
%bcond_with test
%endif
%{?sle15_python_module_pythons}
Name:           python-arrow%{?psuffix}
Version:        1.3.0
Release:        2.8
Summary:        Better dates and times for Python
License:        Apache-2.0
URL:            https://github.com/arrow-py/arrow
Source:         https://files.pythonhosted.org/packages/source/a/arrow/arrow-%{version}.tar.gz
BuildRequires:  %{python_module base >= 3.8}
BuildRequires:  %{python_module flit-core >= 3.2}
BuildRequires:  %{python_module pip}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-python-dateutil >= 2.7.0
BuildArch:      noarch
%if %{with test}
BuildRequires:  %{python_module arrow == %{version}}
BuildRequires:  %{python_module dateparser}
BuildRequires:  %{python_module pytest-mock}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module pytz >= 2021.1}
BuildRequires:  %{python_module simplejson}
%endif
%python_subpackages

%description
Arrow is a Python library that offers a sensible, human-friendly
approach to creating, manipulating, formatting and converting dates,
times, and timestamps.  It implements and updates the datetime type,
plugging gaps in functionality, and provides an intelligent module
API that supports many common creation scenarios.  Simply put, it
helps you work with dates and times with fewer imports and a lot
less code.

Arrow is heavily inspired by moment.js and requests.

%prep
%setup -q -n arrow-%{version}
rm -rf arrow.egg-info
# typing stubs not required for runtime gh#arrow-py/arrow#1169
sed -i '/dependencies = /,/]/ {/types-python-dateutil/d}' pyproject.toml

%build
%pyproject_wheel

%install
%if %{without test}
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}
%endif

%check
%if %{with test}
rm tox.ini
%pytest
%endif

%if %{without test}
%files %{python_files}
%license LICENSE
%doc README.rst
%{python_sitelib}/arrow
%{python_sitelib}/arrow-%{version}*-info
%endif

%changelog
* Fri Jan 12 2024 Ben Greiner <code@bnavigator.de>
- Don't require types-python-dateutil gh#arrow-py/arrow#1169
  in order to shrink the Factory Ring1
* Tue Nov 14 2023 Ondřej Súkup <mimi.vx@gmail.com>
- update to 1.3.0
  * [ADDED] Added official support for Python 3.11 and 3.12.
  * [ADDED] Added dependency on types-python-dateutil to improve Arrow mypy compatibility. PR #1102
  * [FIX] Updates to Italian, Romansh, Hungarian, Finish and Arabic locales.
  * [FIX] Handling parsing of UTC prefix in timezone strings.
  * [CHANGED] Update documentation to improve readability.
  * [CHANGED] Dropped support for Python 3.6 and 3.7, which are end-of-life.
  * [INTERNAL Migrate from setup.py/Twine to pyproject.toml/Flit for packaging and distribution.
* Tue Sep 12 2023 Dirk Müller <dmueller@suse.com>
- drop unnecessary test dependencies to chai (it uses pytest now)
* Fri Apr 21 2023 Dirk Müller <dmueller@suse.com>
- add sle15_python_module_pythons (jsc#PED-68)
* Sat Sep 10 2022 Arun Persaud <arun@gmx.de>
- update to version 1.2.3:
  * [NEW] Added Amharic, Armenian, Georgian, Laotian and Uzbek
    locales.
  * [FIX] Updated Danish locale and associated tests.
  * [INTERNAl] Small fixes to CI.
* Mon Mar  7 2022 pgajdos@suse.com
- python-mock is actually not required
* Sat Jan 29 2022 Arun Persaud <arun@gmx.de>
- specfile:
  * update copyright year
- update to version 1.2.2:
  * [NEW] Added Kazakh locale.
  * [FIX] The Belarusian, Bulgarian, Czech, Macedonian, Polish,
    Russian, Slovak and Ukrainian locales now support dehumanize.
  * [FIX] Minor bug fixes and improvements to ChineseCN, Indonesian,
    Norwegian, and Russian locales.
  * [FIX] Expanded testing for multiple locales.
  * [INTERNAL] Started using xelatex for pdf generation in
    documentation.
  * [INTERNAL] Split requirements file into requirements.txt,
    requirements-docs.txt and requirements-tests.txt.
  * [INTERNAL] Added flake8-annotations package for type linting in
    pre-commit.
* Sat Nov  6 2021 Dirk Müller <dmueller@suse.com>
- update to 1.2.1:
  * Added quarter granularity to humanize
  * Added Sinhala and Urdu locales
  * Support Python 3.10
  * Updated Azerbaijani, Hebrew, and Serbian locale
  * Added Albanian, Tamil and Zulu locales.
  * Added support for Decimal as input to arrow.get().
  * The Estonian, Finnish, Nepali and Zulu locales now support dehumanize.
  * Improved validation checks when using parser tokens A and hh.
  * Minor bug fixes to Catalan, Cantonese, Greek and Nepali locales.
* Sun Jul  4 2021 Dirk Müller <dmueller@suse.com>
- update to 1.1.1:
  * Added Odia, Maltese, Serbian, Sami, and Luxembourgish locales.
  * All calls to ``arrow.get()`` should now properly pass the ``tzinfo``
    argument to the Arrow constructor.
  * Humanize output is now properly truncated when a locale class
    overrides ``_format_timeframe()``.
  * Updated Turkish locale and added tests.
* Tue May 18 2021 Dirk Müller <dmueller@suse.com>
- update to 1.1.0:
  * [NEW] Implemented the ``dehumanize`` method for ``Arrow`` objects.
  * [NEW] Made the start of the week adjustable when using ``span("week")``
  * [NEW] Added Croatian, Latin, Latvian, Lithuanian and Malay locales.
  * [FIX] Internally standardize locales and improve locale validation.
  * [FIX] Correct type checking for ``arrow.get(2021, 3, 9)`` construction.
  * [FIX] Audited all docstrings for style, typos and outdated info.
* Thu Apr 15 2021 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Disable Python2 builds which are no longer supported upstream
* Tue Mar  9 2021 Steve Kowalik <steven.kowalik@suse.com>
- Update to 1.0.3:
  * [FIX] Updated internals to avoid issues when running mypy --strict.
  * [FIX] Corrections to Swedish locale.
  * [INTERNAL] Lowered required coverage limit until humanize month tests are
    fixed.
  * [FIXED] Fixed an OverflowError that could occur when running Arrow on a
    32-bit OS.
  * [FIXED] A py.typed file is now bundled with the Arrow package to conform
    to PEP 561.
  * [CHANGE] Arrow has dropped support for Python 2.7 and 3.5.
  * [CHANGE] There are multiple breaking changes with this release, please see
    the migration guide for a complete overview.
  * [CHANGE] Made humanize granularity="auto" limits more accurate to reduce
    strange results.
  * [NEW] Added support for Python 3.9.
  * [NEW] Added a new keyword argument "exact" to span, span_range and
    interval methods. This makes timespans begin at the start time given and
    not extend beyond the end time given.
  * [NEW] Arrow now natively supports PEP 484-style type annotations.
  * [FIX] Fixed handling of maximum permitted timestamp on Windows systems.
  * [FIX] Corrections to French, German, Japanese and Norwegian locales.
* Fri Oct 30 2020 Arun Persaud <arun@gmx.de>
- update to version 0.17.0:
  * [WARN] Arrow will drop support for Python 2.7 and 3.5 in the
    upcoming 1.0.0 release. This is the last major release to support
    Python 2.7 and Python 3.5.
  * [NEW] Arrow now properly handles imaginary datetimes during DST
    shifts.
  * [NEW] Added humanize week granularity translation for Tagalog.
  * [CHANGE] Calls to the timestamp property now emit a
    DeprecationWarning. In a future release, timestamp will be changed
    to a method to align with Python’s datetime module. If you would
    like to continue using the property, please change your code to
    use the int_timestamp or float_timestamp properties instead.
  * [CHANGE] Expanded and improved Catalan locale.
  * [FIX] Fixed a bug that caused Arrow.range() to incorrectly cut off
    ranges in certain scenarios when using month, quarter, or year
    endings.
  * [FIX] Fixed a bug that caused day of week token parsing to be case
    sensitive.
  * [INTERNAL] A number of functions were reordered in arrow.py for
    better organization and grouping of related methods. This change
    will have no impact on usage.
  * [INTERNAL] A minimum tox version is now enforced for compatibility
    reasons. Contributors must use tox >3.18.0 going forward.
* Sat Sep 19 2020 Arun Persaud <arun@gmx.de>
- update to version 0.16.0:
  * [WARN] Arrow will drop support for Python 2.7 and 3.5 in the 1.0.0
    release in late September. The 0.16.x and 0.17.x releases are the
    last to support Python 2.7 and 3.5.
  * [NEW] Implemented PEP 495 to handle ambiguous datetimes. This is
    achieved by the addition of the fold attribute for Arrow objects.
  * [NEW] Added normalize_whitespace flag to arrow.get. This is useful
    for parsing log files and/or any files that may contain
    inconsistent spacing.
* Sat Jul 25 2020 Arun Persaud <arun@gmx.de>
- specfile:
  * updated url
- update to version 0.15.8:
  * [WARN] arrow will drop support for Python 2.7 and 3.5 in the 1.0.0
    release in late September. The 0.15.x and 0.16.x releases are the
    last to support Python 2.7 and 3.5.
  * [NEW] Added humanize week granularity translation for Czech.
  * [FIX] arrow.get will now pick sane defaults when weekdays are
    passed with particular token combinations, see #446.
  * [INTERNAL] Moved arrow to an organization. The repo can now be
    found here.
  * [INTERNAL] Started issuing deprecation warnings for Python 2.7 and
    3.5.
  * [INTERNAL] Added Python 3.9 to CI pipeline.
* Sun Jul 12 2020 Arun Persaud <arun@gmx.de>
- update to version 0.15.7:
  * [NEW] Added a number of built-in format strings. See the docs for
    a complete list of supported formats. For example:
    >>> arw = arrow.utcnow()
    >>> arw.format(arrow.FORMAT_COOKIE)
    'Wednesday, 27-May-2020 10:30:35 UTC'
  * [NEW] Arrow is now fully compatible with Python 3.9 and PyPy3.
  * [NEW] Added Makefile, tox.ini, and requirements.txt files to the
    distribution bundle.
  * [NEW] Added French Canadian and Swahili locales.
  * [NEW] Added humanize week granularity translation for Hebrew,
    Greek, Macedonian, Swedish, Slovak.
  * [FIX] ms and μs timestamps are now normalized in arrow.get(),
    arrow.fromtimestamp(), and arrow.utcfromtimestamp(). For example:
    >>> ts = 1591161115194556
    >>> arw = arrow.get(ts)
    <Arrow [2020-06-03T05:11:55.194556+00:00]>
    >>> arw.timestamp
    1591161115
  * [FIX] Refactored and updated Macedonian, Hebrew, Korean, and
    Portuguese locales.
* Fri May 15 2020 Benjamin Greiner <code@bnavigator.de>
- new version needs pytest instead of nose
* Tue May 12 2020 Dirk Mueller <dmueller@suse.com>
- update to 0.15.6:
  - [NEW] Added ``humanize`` week granularity translation for German, Italian, Polish & Taiwanese locales.
  - [FIX] Consolidated and simplified German locales.
* Sun Jan  5 2020 Arun Persaud <arun@gmx.de>
- specfile:
  * update copyright year
- update to version 0.15.5:
  * [WARN] Python 2 reached EOL on 2020-01-01. arrow will drop support
    for Python 2 in a future release to be decided (see #739).
  * [NEW] Added bounds parameter to span_range, interval and span
    methods. This allows you to include or exclude the start and end
    values.
  * [NEW] arrow.get() can now create arrow objects from a timestamp
    with a timezone, for example:
    >>> arrow.get(1367900664, tzinfo=tz.gettz('US/Pacific'))
    <Arrow [2013-05-06T21:24:24-07:00]>
  * [NEW] humanize can now combine multiple levels of granularity, for
    example:
    >>> later140 = arrow.utcnow().shift(seconds=+8400)
    >>> later140.humanize(granularity="minute")
    'in 139 minutes'
    >>> later140.humanize(granularity=["hour", "minute"])
    'in 2 hours and 19 minutes'
  * [NEW] Added Hong Kong locale (zh_hk).
  * [NEW] Added humanize week granularity translation for Dutch.
  * [NEW] Numbers are now displayed when using the seconds granularity
    in humanize.
  * [CHANGE] range now supports both the singular and plural forms of
    the frames argument (e.g. day and days).
  * [FIX] Improved parsing of strings that contain punctuation.
  * [FIX] Improved behaviour of humanize when singular seconds are
    involved.
* Sat Dec 14 2019 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Use _multibuild for tests to reduce the build dependencies
  and simplify bootstrap for e.g. rpmlint.
* Sat Nov  9 2019 Arun Persaud <arun@gmx.de>
- update to version 0.15.4:
  * [FIX] Fixed an issue that caused package installs to fail on Conda
    Forge.
- changes from version 0.15.3:
  * [NEW] factory.get() can now create arrow objects from a ISO
    calendar tuple, for example:
    >>> arrow.get((2013, 18, 7))
  <Arrow [2013-05-05T00:00:00+00:00]>
  * [NEW] Added a new token x to allow parsing of integer timestamps
    with milliseconds and microseconds.
  * [NEW] Formatting now supports escaping of characters using the
    same syntax as parsing, for example:
    >>> arw = arrow.now()
    >>> fmt = "YYYY-MM-DD h [h] m"
    >>> arw.format(fmt)
    '2019-11-02 3 h 32'
  * [NEW] Added humanize week granularity translations for Chinese,
    Spanish and Vietnamese.
  * [CHANGE] Added ParserError to module exports.
  * [FIX] Added support for midnight at end of day. See #703 for
    details.
  * [INTERNAL] Created Travis build for macOS.
  * [INTERNAL] Test parsing and formatting against full timezone
    database.
* Tue Sep 17 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 0.15.2:
  * [NEW] Added humanize week granularity translations for Portuguese and Brazilian Portuguese.
  * [NEW] Embedded changelog within docs and added release dates to versions.
  * [FIX] Fixed a bug that caused test failures on Windows only, see #668 for details.
* Fri Sep 13 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 0.15.1:
  * Too many changes to enumerate, see CHANGELOG.rst
* Sun Aug  4 2019 Arun Persaud <arun@gmx.de>
- update to version 0.14.4:
  * [FIX] Fixed a regression in 0.14.3 that prevented a tzinfo
    argument of type string to be passed to the get()
    function. Functionality such as arrow.get("2019072807",
    "YYYYMMDDHH", tzinfo="UTC") should work as normal again.
  * [CHANGE] Moved backports.functools_lru_cache dependency from
    extra_requires to install_requires for Python 2.7 installs to fix
    [#495].
* Sun Jul 28 2019 Arun Persaud <arun@gmx.de>
- update to version 0.14.3:
  * [NEW] Added full support for Python 3.8.
  * [CHANGE] Added warnings for upcoming factory.get() parsing changes
    in 0.15.0. Please see
    https://github.com/crsmithdev/arrow/issues/612 for full details.
  * [FIX] Extensive refactor and update of documentation.
  * [FIX] factory.get() can now construct from kwargs.
  * [FIX] Added meridians to Spanish Locale.
* Sat Jun  8 2019 Arun Persaud <arun@gmx.de>
- update to version 0.14.2:
  * [CHANGE] Travis CI builds now use tox to lint and run tests.
  * [FIX] Fixed UnicodeDecodeError on certain locales (#600).
- changes from version 0.14.1:
  * [FIX] Fixed "ImportError: No module named 'dateutil'" (#598).
- changes from version 0.14.0:
  * [NEW] Added provisional support for Python 3.8.
  * [CHANGE] Removed support for EOL Python 3.4.
  * [FIX] Updated setup.py with modern Python standards.
  * [FIX] Upgraded dependencies to latest versions.
  * [FIX] Enabled flake8 and black on travis builds.
  * [FIX] Formatted code using black and isort.
- changes from version 0.13.2:
  * [NEW] Add is_between method.
  * [FIX] Improved humanize behaviour for near zero durations (#416).
  * [FIX] Correct humanize behaviour with future days (#541).
  * [FIX] Documentation updates.
  * [FIX] Improvements to German Locale.
* Wed Mar  6 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 0.13.1:
  * Support for python3.7
- Remove merged patch arrow-py37.patch
* Tue Jan 22 2019 Tomáš Chvátal <tchvatal@suse.com>
- Add patch to work with python 3.7:
  * arrow-py37.patch
* Sun Jan 20 2019 Arun Persaud <arun@gmx.de>
- specfile:
  * update copyright year
  * be more specific in %%files section
  * require pytz
- update to version 0.13.0:
  * [NEW] Added support for Python 3.6.
  * [CHANGE] Drop support for Python 2.6/3.3.
  * [CHANGE] Return generator instead of list for Arrow.range(),
    Arrow.span_range() and Arrow.interval().
  * [FIX] Make arrow.get() work with str & tzinfo combo.
  * [FIX] Make sure special RegEx characters are escaped in format
    string.
  * [NEW] Added support for ZZZ when formatting.
  * [FIX] Stop using datetime.utcnow() in internals, use
    datetime.now(UTC) instead.
  * [FIX] Return NotImplemented instead of TypeError in arrow math
    internals.
  * [NEW] Added Estonian Locale.
  * [FIX] Small fixes to Greek locale.
  * [FIX] TagalogLocale improvements.
  * [FIX] Added test requirements to setup.
  * [FIX] Improve docs for get, now and utcnow methods.
  * [FIX] Correct typo in depreciation warning.
* Tue Dec  4 2018 Matej Cepl <mcepl@suse.com>
- Remove superfluous devel dependency for noarch package
* Tue Feb 20 2018 arun@gmx.de
- specfile:
  * also require python-backports.functools_lru_cache during
    installation
* Sat Feb 17 2018 arun@gmx.de
- specfile:
  * update copyright year
  * require python-backports.functools_lru_cache for python2
- update to version 0.12.1:
  * Allow wheels to determine the required dependencies
  * Makes the only_distance paramter value equivalent to value given
    to function when granularity paramter is also provided by user
- changes from version 0.12.0:
  * [FIX] Compatibility fix for Python 2.x
- changes from version 0.11.0:
  * [FIX] Fix grammar of ArabicLocale
  * [NEW] Add Nepali Locale
  * [FIX] Fix month name + rename AustriaLocale -> AustrianLocale
  * [FIX] Fix typo in Basque Locale
  * [FIX] Fix grammar in PortugueseBrazilian locale
  * [FIX] Remove pip --user-mirrors flag
  * [NEW] Add Indonesian Locale
* Sat Jul 15 2017 aloisio@gmx.com
- Update to 0.10.0 (see HISTORY.md)
- Converted to singlespec
* Fri Feb 26 2016 tbechtold@suse.com
- Require python-python-dateutil. package was renamed
* Wed Aug  6 2014 toddrme2178@gmail.com
- Initial version
